// texts to translate
var texts = {
    selection : "Filtration",
    netselection : "Graph selection",
    visualization : "Visualization",
    nodes : "Nodes",
    general: "General",
    particular: "Specific",
    links: "Links",
    apply: "Apply",
    filter: "Filter",
    select: "Select",
    clear: "Clear",
    add: "Add",
    simpleadvanced: "Simple/advanced",
    nodesattributes: "Node attributes",
    linksattributes: "Link attributes",
    noitemsselected: "No items selected",
    alertnonodes: "No nodes selected! Hold shift to select nodes.",
    alertnonodestable: "No nodes selected in table!",
    repulsion: "Repulsion",
    distance: "Distance",
    loading: "Loading...",
    pdfexport: "PDF export",
    svgexport: "SVG export",
	adjustsymbols: "Adjust symbols",
    showhidelabels: "Show/hide labels",
    showhidelegend: "Show/hide legend",
    showhideaxes: "Show/hide axes",
    stopresume: "Stop/resume",
	netheatmap: "Net/heatmap",
    isolateselection: "Filter selection",
    resetfilter: "Reset filter",
    selectall: "Select all/none",
    selectneighbors: "Add neighbors",
    egoNet: "EgoNet",
    tableselection: "Matched in table",
    reset: "Reset",
    directional: "Directional arrows",
    degree: "degree",
    none: "none",
    downloadtable: "Download table",
    total: "Total",
    concoincidences: "Conditional coincidences",
    coincidences: "Coincidences",
    ofsomeone: "of",
    withsomeone: "with",
    incidences: "Incidences",
    ltexpected: "< Expected",
    gtexpected: "> Expected",
    confidence: "Confidence interval",
    subjectselect: "Event selection",
    Label: "Label",
    Group: "Group",
	OrderA: "A Order",
	OrderD: "D Order",
    Size: "Size",
    Color: "Color",
    Shape: "Shape",
    Width: "Width",
    Weight: "Weight",
	Intensity: "Intensity",
    Text: "Text",
    Show: "Show",
    Hide: "Hide",
    circle: "circle",
    cross: "cross",
    diamond: "diamond",
    square: "square",
    "triangle-down": "triangle-down",
    "triangle-up": "triangle-up",
	trianglesquare: "Triangle/square",
	selectacolorscale: "Select a color scale for ",
    selecta: "Select a ",
	outof: "out of"
  };
